@@ -27,7 +27,6 @@ data_arrange <- function(data, select = NULL, safe = TRUE) {
 }
 
 
-
 #' @export
 data_arrange.default <- function(data, select = NULL, safe = TRUE) {
   if (is.null(select) || length(select) == 0) {
@@ -43,11 +42,11 @@ data_arrange.default <- function(data, select = NULL, safe = TRUE) {
   select <- gsub("^-", "", select)
 
   # check for variables that are not in data
-  dont_exist <- select[which(!select %in% names(data))]
+  dont_exist <- setdiff(select, colnames(data))
 
   if (length(dont_exist) > 0) {
-    if (!safe) {
-      insight::format_error(
+    if (safe) {
+      insight::format_warning(
         paste0(
           "The following column(s) don't exist in the dataset: ",
           text_concatenate(dont_exist), "."
@@ -55,7 +54,7 @@ data_arrange.default <- function(data, select = NULL, safe = TRUE) {
         .misspelled_string(names(data), dont_exist, "Possibly misspelled?")
       )
     } else {
-      insight::format_warning(
+      insight::format_error(
         paste0(
           "The following column(s) don't exist in the dataset: ",
           text_concatenate(dont_exist), "."
@@ -100,10 +99,8 @@ data_arrange.default <- function(data, select = NULL, safe = TRUE) {
 }
 
 
-
 #' @export
 data_arrange.grouped_df <- function(data, select = NULL, safe = TRUE) {
-  # works only for dplyr >= 0.8.0
   grps <- attr(data, "groups", exact = TRUE)
   grps <- grps[[".rows"]]
 
